==> BerkeleyDB-0.7.tar.gz: BerkeleyDB-0.7/Database/Berkeley/db_helper.h <==
#ifndef _DB_HELPER_H_
#define _DB_HELPER_H_

#if defined(USE_DB_CXX)
#include <db_cxx.h>
#define MY_DBENV DbEnv
#define MY_DBTXN DbTxn
#else
#include <db.h>
#define MY_DBENV DB_ENV*
#define MY_DBTXN DB_TXN
#endif

typedef struct _DB_LOCK {
    MY_DBENV* dbenv;
    DB_LOCK lock;
} _DB_LOCK;



#if defined(USE_DB_CXX)
extern "C" {
#endif
int _dbenv_create(MY_DBENV** dbenvpp, u_int32_t flags);
void _dbenv_delete(MY_DBENV* dbenvp);
int _dbenv_get_lk_max_lockers(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lk_max_lockers(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_lk_max_locks(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lk_max_locks(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_lk_max_objects(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lk_max_objects(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_tx_max(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_tx_max(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_cachesize(MY_DBENV* dbenvp, u_int32_t *gbytesp, u_int32_t *bytesp, int *ncachep);
int _dbenv_set_cachesize(MY_DBENV* dbenvp, u_int32_t gbytes, u_int32_t bytes, int ncache);
int _dbenv_get_lg_regionmax(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lg_regionmax(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_set_lk_detect(MY_DBENV* dbEnv, u_int32_t flag);
int _dbenv_open(MY_DBENV* dbenvp, char *db_home, u_int32_t flags, int mode);
int _dbenv_close(MY_DBENV* dbEnv, u_int32_t flags);
int _db_create(DB*** dbpp, MY_DBENV* dbenvp, u_int32_t flags);
void _db_delete(DB** db);
int _db_set_pagesize(DB** dbp, u_int32_t pagesize);
int _db_open(DB** dbp, MY_DBTXN** txnp, const char* file, const char* database,
    int type, u_int32_t flags, int mode);
int _dbenv_txn_begin(MY_DBENV* dbenvp, MY_DBTXN** parent, MY_DBTXN*** txnpp, u_int32_t flags);
int _dbenv_txn_checkpoint(MY_DBENV* dbenvp, u_int32_t kbyte, u_int32_t min, u_int32_t flags);
int _dbtxn_abort(MY_DBTXN** dbtxnp);
int _dbtxn_commit(MY_DBTXN** dbtxnp, u_int32_t flags);
void _dbtxn_delete(MY_DBTXN** dbtxnp);
u_int32_t _dbtxn_id(MY_DBTXN** dbtxnp);
void _dblock_delete(_DB_LOCK* dblock);
int _dbenv_lock_get(MY_DBENV* dbenvp, u_int32_t lockerID, u_int32_t flags,
    const char* object, u_int32_t object_len, u_int32_t lockmode, _DB_LOCK** dblock);
int _dbenv_lock_put(_DB_LOCK* dblock);
void _deleteString(char* str);
void _freeString(char* str);
int _db_get(DB** dbp, MY_DBTXN** dbtxnp, const char* key, u_int32_t key_len, char** value, u_int32_t* value_len, u_int32_t flags);
int _db_put(DB** dbp, MY_DBTXN** dbtxnp, const char* key, u_int32_t key_len, const char* value, u_int32_t value_len, u_int32_t flags);
int _db_del(DB** dbp, MY_DBTXN** dbtxnp, const char* key, u_int32_t key_len, u_int32_t flags);
int _db_close(DB** dbp, u_int32_t flags);
int _db_cursor(DB** dbp, MY_DBTXN** dbtxnp, DBC*** dbcursorpp, u_int32_t flags);
void _dbcursor_delete(DBC** dbc);
int _dbCursor_close(DBC** dbc);
int _dbCursor_count(DBC** dbcp, u_int32_t* countp, u_int32_t flags);
int _dbCursor_del(DBC** dbcp, u_int32_t flags);
int _dbCursor_dup(DBC** dbcp, DBC*** dbcursorpp, u_int32_t flags);
int _dbCursor_get(DBC** dbcp, char** key, u_int32_t* key_len, char** value, u_int32_t* value_len, u_int32_t flags);
int _dbCursor_set(DBC** dbcp, const char* key, u_int32_t key_len, char** value, u_int32_t* value_len, u_int32_t flags);
int _dbCursor_put(DBC** dbcp, const char* key, u_int32_t key_len, const char* value, u_int32_t value_len, u_int32_t flags);
#if defined(USE_DB_CXX)
}
#endif

#endif

==> BerkeleyDB-0.8.1.tar.gz: BerkeleyDB-0.8.1/Database/Berkeley/db_helper.h <==
#ifndef _DB_HELPER_H_
#define _DB_HELPER_H_

#include <db.h>
#define MY_DBENV DB_ENV*

typedef struct _DB_LOCK {
    MY_DBENV* dbenv;
    DB_LOCK lock;
} _DB_LOCK;


int _dbenv_create(MY_DBENV** dbenvpp, u_int32_t flags);
int _dbenv_get_lk_max_lockers(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lk_max_lockers(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_lk_max_locks(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lk_max_locks(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_lk_max_objects(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lk_max_objects(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_tx_max(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_tx_max(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_get_cachesize(MY_DBENV* dbenvp, u_int32_t *gbytesp, u_int32_t *bytesp, int *ncachep);
int _dbenv_set_cachesize(MY_DBENV* dbenvp, u_int32_t gbytes, u_int32_t bytes, int ncache);
int _dbenv_get_lg_regionmax(MY_DBENV* dbenvp, u_int32_t *lk_maxp);
int _dbenv_set_lg_regionmax(MY_DBENV* dbenvp, u_int32_t max);
int _dbenv_set_lk_detect(MY_DBENV* dbEnv, u_int32_t flag);
int _dbenv_open(MY_DBENV* dbenvp, char *db_home, u_int32_t flags, int mode);
int _dbenv_close(MY_DBENV* dbEnv, u_int32_t flags);
int _db_create(DB*** dbpp, MY_DBENV* dbenvp, u_int32_t flags);
void _db_delete(DB** db);
int _db_set_pagesize(DB** dbp, u_int32_t pagesize);
int _db_open(DB** dbp, DB_TXN** txnp, const char* file, const char* database,
    int type, u_int32_t flags, int mode);
int _dbenv_txn_begin(MY_DBENV* dbenvp, DB_TXN** parent, DB_TXN*** txnpp, u_int32_t flags);
int _dbenv_txn_checkpoint(MY_DBENV* dbenvp, u_int32_t kbyte, u_int32_t min, u_int32_t flags);
int _dbtxn_abort(DB_TXN** dbtxnp);
int _dbtxn_commit(DB_TXN** dbtxnp, u_int32_t flags);
void _dbtxn_delete(DB_TXN** dbtxnp);
int _dbtxn_id(DB_TXN** dbtxnp, u_int32_t* locker);
void _dblock_delete(_DB_LOCK* dblock);
int _dbenv_lock_get(MY_DBENV* dbenvp, u_int32_t lockerID, u_int32_t flags,
    const char* object, u_int32_t object_len, u_int32_t lockmode, _DB_LOCK** dblock);
int _dbenv_lock_put(_DB_LOCK* dblock);
void _deleteString(char* str);
void _freeString(char* str);
int _db_get(DB** dbp, DB_TXN** dbtxnp, const char* key, u_int32_t key_len, char** value, u_int32_t* value_len, u_int32_t flags);
int _db_put(DB** dbp, DB_TXN** dbtxnp, const char* key, u_int32_t key_len, const char* value, u_int32_t value_len, u_int32_t flags);
int _db_del(DB** dbp, DB_TXN** dbtxnp, const char* key, u_int32_t key_len, u_int32_t flags);
int _db_close(DB** dbp, u_int32_t flags);
int _db_cursor(DB** dbp, DB_TXN** dbtxnp, DBC*** dbcursorpp, u_int32_t flags);
void _dbcursor_delete(DBC** dbc);
int _dbCursor_close(DBC** dbc);
int _dbCursor_count(DBC** dbcp, u_int32_t* countp, u_int32_t flags);
int _dbCursor_del(DBC** dbcp, u_int32_t flags);
int _dbCursor_dup(DBC** dbcp, DBC*** dbcursorpp, u_int32_t flags);
int _dbCursor_get(DBC** dbcp, char** key, u_int32_t* key_len, char** value, u_int32_t* value_len, u_int32_t flags);
int _dbCursor_set(DBC** dbcp, const char* key, u_int32_t key_len, char** value, u_int32_t* value_len, u_int32_t flags);
int _dbCursor_put(DBC** dbcp, const char* key, u_int32_t key_len, const char* value, u_int32_t value_len, u_int32_t flags);

#endif
